# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        HealthStatus,
        Product,
        ProductConfig,
        ProductConfigAddOn1Tb,
        ProductConfigAddOn1TbId,
        ProductConfigAddOn200Gb,
        ProductConfigAddOn200GbId,
        ProductConfigAddOn500Gb,
        ProductConfigAddOn500GbId,
        ProductConfigChatAgent,
        ProductConfigChatAgentId,
        ProductConfigChatintegrationProfessional,
        ProductConfigChatintegrationProfessionalId,
        ProductConfigChatintegrationStarter,
        ProductConfigChatintegrationStarterId,
        ProductConfigDeveloper,
        ProductConfigDeveloperId,
        ProductConfigProjectroom,
        ProductConfigProjectroomId,
        UploadResponse,
        VectorUpdateResponse,
    )
    from .client import AsyncConcreteApi, ConcreteApi
    from .environment import ConcreteApiEnvironment
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AsyncConcreteApi": ".client",
    "ConcreteApi": ".client",
    "ConcreteApiEnvironment": ".environment",
    "HealthStatus": ".types",
    "Product": ".types",
    "ProductConfig": ".types",
    "ProductConfigAddOn1Tb": ".types",
    "ProductConfigAddOn1TbId": ".types",
    "ProductConfigAddOn200Gb": ".types",
    "ProductConfigAddOn200GbId": ".types",
    "ProductConfigAddOn500Gb": ".types",
    "ProductConfigAddOn500GbId": ".types",
    "ProductConfigChatAgent": ".types",
    "ProductConfigChatAgentId": ".types",
    "ProductConfigChatintegrationProfessional": ".types",
    "ProductConfigChatintegrationProfessionalId": ".types",
    "ProductConfigChatintegrationStarter": ".types",
    "ProductConfigChatintegrationStarterId": ".types",
    "ProductConfigDeveloper": ".types",
    "ProductConfigDeveloperId": ".types",
    "ProductConfigProjectroom": ".types",
    "ProductConfigProjectroomId": ".types",
    "UploadResponse": ".types",
    "VectorUpdateResponse": ".types",
    "__version__": ".version",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AsyncConcreteApi",
    "ConcreteApi",
    "ConcreteApiEnvironment",
    "HealthStatus",
    "Product",
    "ProductConfig",
    "ProductConfigAddOn1Tb",
    "ProductConfigAddOn1TbId",
    "ProductConfigAddOn200Gb",
    "ProductConfigAddOn200GbId",
    "ProductConfigAddOn500Gb",
    "ProductConfigAddOn500GbId",
    "ProductConfigChatAgent",
    "ProductConfigChatAgentId",
    "ProductConfigChatintegrationProfessional",
    "ProductConfigChatintegrationProfessionalId",
    "ProductConfigChatintegrationStarter",
    "ProductConfigChatintegrationStarterId",
    "ProductConfigDeveloper",
    "ProductConfigDeveloperId",
    "ProductConfigProjectroom",
    "ProductConfigProjectroomId",
    "UploadResponse",
    "VectorUpdateResponse",
    "__version__",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from . import core
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.logging import LogConfig, Logger
from .core.request_options import RequestOptions
from .environment import ConcreteApiEnvironment
from .raw_client import AsyncRawConcreteApi, RawConcreteApi
from .types.health_status import HealthStatus
from .types.upload_response import UploadResponse
from .types.vector_update_response import VectorUpdateResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ConcreteApi:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ConcreteApiEnvironment
        The environment to use for requests from the client. from .environment import ConcreteApiEnvironment



        Defaults to ConcreteApiEnvironment.DEFAULT



    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    logging : typing.Optional[typing.Union[LogConfig, Logger]]
        Configure logging for the SDK. Accepts a LogConfig dict with 'level' (debug/info/warn/error), 'logger' (custom logger implementation), and 'silent' (boolean, defaults to True) fields. You can also pass a pre-configured Logger instance.

    Examples
    --------
    from concrete import ConcreteApi

    client = ConcreteApi()
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ConcreteApiEnvironment = ConcreteApiEnvironment.DEFAULT,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
        logging: typing.Optional[typing.Union[LogConfig, Logger]] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            logging=logging,
        )
        self._raw_client = RawConcreteApi(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> RawConcreteApi:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawConcreteApi
        """
        return self._raw_client

    def get_health(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthStatus:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthStatus
            OK

        Examples
        --------
        from concrete import ConcreteApi

        client = ConcreteApi()
        client.get_health()
        """
        _response = self._raw_client.get_health(request_options=request_options)
        return _response.data

    def upload_file(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UploadResponse:
        """
        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]
            Optional JSON metadata associated with the file

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UploadResponse
            File successfully uploaded

        Examples
        --------
        from concrete import ConcreteApi

        client = ConcreteApi()
        client.upload_file()
        """
        _response = self._raw_client.upload_file(file=file, metadata=metadata, request_options=request_options)
        return _response.data

    def start_vector_update(self, *, request_options: typing.Optional[RequestOptions] = None) -> VectorUpdateResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        VectorUpdateResponse
            Vector update started successfully

        Examples
        --------
        from concrete import ConcreteApi

        client = ConcreteApi()
        client.start_vector_update()
        """
        _response = self._raw_client.start_vector_update(request_options=request_options)
        return _response.data


class AsyncConcreteApi:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ConcreteApiEnvironment
        The environment to use for requests from the client. from .environment import ConcreteApiEnvironment



        Defaults to ConcreteApiEnvironment.DEFAULT



    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    logging : typing.Optional[typing.Union[LogConfig, Logger]]
        Configure logging for the SDK. Accepts a LogConfig dict with 'level' (debug/info/warn/error), 'logger' (custom logger implementation), and 'silent' (boolean, defaults to True) fields. You can also pass a pre-configured Logger instance.

    Examples
    --------
    from concrete import AsyncConcreteApi

    client = AsyncConcreteApi()
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ConcreteApiEnvironment = ConcreteApiEnvironment.DEFAULT,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
        logging: typing.Optional[typing.Union[LogConfig, Logger]] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            logging=logging,
        )
        self._raw_client = AsyncRawConcreteApi(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawConcreteApi:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawConcreteApi
        """
        return self._raw_client

    async def get_health(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthStatus:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthStatus
            OK

        Examples
        --------
        import asyncio

        from concrete import AsyncConcreteApi

        client = AsyncConcreteApi()


        async def main() -> None:
            await client.get_health()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_health(request_options=request_options)
        return _response.data

    async def upload_file(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UploadResponse:
        """
        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]
            Optional JSON metadata associated with the file

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UploadResponse
            File successfully uploaded

        Examples
        --------
        import asyncio

        from concrete import AsyncConcreteApi

        client = AsyncConcreteApi()


        async def main() -> None:
            await client.upload_file()


        asyncio.run(main())
        """
        _response = await self._raw_client.upload_file(file=file, metadata=metadata, request_options=request_options)
        return _response.data

    async def start_vector_update(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> VectorUpdateResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        VectorUpdateResponse
            Vector update started successfully

        Examples
        --------
        import asyncio

        from concrete import AsyncConcreteApi

        client = AsyncConcreteApi()


        async def main() -> None:
            await client.start_vector_update()


        asyncio.run(main())
        """
        _response = await self._raw_client.start_vector_update(request_options=request_options)
        return _response.data


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ConcreteApiEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .health_status import HealthStatus
    from .product import Product
    from .product_config import ProductConfig
    from .product_config_add_on1tb import ProductConfigAddOn1Tb
    from .product_config_add_on1tb_id import ProductConfigAddOn1TbId
    from .product_config_add_on200gb import ProductConfigAddOn200Gb
    from .product_config_add_on200gb_id import ProductConfigAddOn200GbId
    from .product_config_add_on500gb import ProductConfigAddOn500Gb
    from .product_config_add_on500gb_id import ProductConfigAddOn500GbId
    from .product_config_chat_agent import ProductConfigChatAgent
    from .product_config_chat_agent_id import ProductConfigChatAgentId
    from .product_config_chatintegration_professional import ProductConfigChatintegrationProfessional
    from .product_config_chatintegration_professional_id import ProductConfigChatintegrationProfessionalId
    from .product_config_chatintegration_starter import ProductConfigChatintegrationStarter
    from .product_config_chatintegration_starter_id import ProductConfigChatintegrationStarterId
    from .product_config_developer import ProductConfigDeveloper
    from .product_config_developer_id import ProductConfigDeveloperId
    from .product_config_projectroom import ProductConfigProjectroom
    from .product_config_projectroom_id import ProductConfigProjectroomId
    from .upload_response import UploadResponse
    from .vector_update_response import VectorUpdateResponse
_dynamic_imports: typing.Dict[str, str] = {
    "HealthStatus": ".health_status",
    "Product": ".product",
    "ProductConfig": ".product_config",
    "ProductConfigAddOn1Tb": ".product_config_add_on1tb",
    "ProductConfigAddOn1TbId": ".product_config_add_on1tb_id",
    "ProductConfigAddOn200Gb": ".product_config_add_on200gb",
    "ProductConfigAddOn200GbId": ".product_config_add_on200gb_id",
    "ProductConfigAddOn500Gb": ".product_config_add_on500gb",
    "ProductConfigAddOn500GbId": ".product_config_add_on500gb_id",
    "ProductConfigChatAgent": ".product_config_chat_agent",
    "ProductConfigChatAgentId": ".product_config_chat_agent_id",
    "ProductConfigChatintegrationProfessional": ".product_config_chatintegration_professional",
    "ProductConfigChatintegrationProfessionalId": ".product_config_chatintegration_professional_id",
    "ProductConfigChatintegrationStarter": ".product_config_chatintegration_starter",
    "ProductConfigChatintegrationStarterId": ".product_config_chatintegration_starter_id",
    "ProductConfigDeveloper": ".product_config_developer",
    "ProductConfigDeveloperId": ".product_config_developer_id",
    "ProductConfigProjectroom": ".product_config_projectroom",
    "ProductConfigProjectroomId": ".product_config_projectroom_id",
    "UploadResponse": ".upload_response",
    "VectorUpdateResponse": ".vector_update_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "HealthStatus",
    "Product",
    "ProductConfig",
    "ProductConfigAddOn1Tb",
    "ProductConfigAddOn1TbId",
    "ProductConfigAddOn200Gb",
    "ProductConfigAddOn200GbId",
    "ProductConfigAddOn500Gb",
    "ProductConfigAddOn500GbId",
    "ProductConfigChatAgent",
    "ProductConfigChatAgentId",
    "ProductConfigChatintegrationProfessional",
    "ProductConfigChatintegrationProfessionalId",
    "ProductConfigChatintegrationStarter",
    "ProductConfigChatintegrationStarterId",
    "ProductConfigDeveloper",
    "ProductConfigDeveloperId",
    "ProductConfigProjectroom",
    "ProductConfigProjectroomId",
    "UploadResponse",
    "VectorUpdateResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .product_config_add_on1tb import ProductConfigAddOn1Tb
from .product_config_add_on200gb import ProductConfigAddOn200Gb
from .product_config_add_on500gb import ProductConfigAddOn500Gb
from .product_config_chat_agent import ProductConfigChatAgent
from .product_config_chatintegration_professional import ProductConfigChatintegrationProfessional
from .product_config_chatintegration_starter import ProductConfigChatintegrationStarter
from .product_config_developer import ProductConfigDeveloper
from .product_config_projectroom import ProductConfigProjectroom


class ProductConfig(UniversalBaseModel):
    developer: typing.Optional[ProductConfigDeveloper] = None
    projectroom: typing.Optional[ProductConfigProjectroom] = None
    chatintegration_starter: typing_extensions.Annotated[
        typing.Optional[ProductConfigChatintegrationStarter],
        FieldMetadata(alias="chatintegration-starter"),
        pydantic.Field(alias="chatintegration-starter"),
    ] = None
    chatintegration_professional: typing_extensions.Annotated[
        typing.Optional[ProductConfigChatintegrationProfessional],
        FieldMetadata(alias="chatintegration-professional"),
        pydantic.Field(alias="chatintegration-professional"),
    ] = None
    add_on200gb: typing_extensions.Annotated[
        typing.Optional[ProductConfigAddOn200Gb],
        FieldMetadata(alias="add-on-200gb"),
        pydantic.Field(alias="add-on-200gb"),
    ] = None
    add_on500gb: typing_extensions.Annotated[
        typing.Optional[ProductConfigAddOn500Gb],
        FieldMetadata(alias="add-on-500gb"),
        pydantic.Field(alias="add-on-500gb"),
    ] = None
    add_on1tb: typing_extensions.Annotated[
        typing.Optional[ProductConfigAddOn1Tb], FieldMetadata(alias="add-on-1tb"), pydantic.Field(alias="add-on-1tb")
    ] = None
    chat_agent: typing_extensions.Annotated[
        typing.Optional[ProductConfigChatAgent], FieldMetadata(alias="chat-agent"), pydantic.Field(alias="chat-agent")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from . import core
from .core.api_error import ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.http_response import AsyncHttpResponse, HttpResponse
from .core.parse_error import ParsingError
from .core.pydantic_utilities import parse_obj_as
from .core.request_options import RequestOptions
from .types.health_status import HealthStatus
from .types.upload_response import UploadResponse
from .types.vector_update_response import VectorUpdateResponse
from pydantic import ValidationError

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawConcreteApi:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_health(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[HealthStatus]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[HealthStatus]
            OK
        """
        _response = self._client_wrapper.httpx_client.request(
            "health",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    HealthStatus,
                    parse_obj_as(
                        type_=HealthStatus,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def upload_file(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[UploadResponse]:
        """
        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]
            Optional JSON metadata associated with the file

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[UploadResponse]
            File successfully uploaded
        """
        _response = self._client_wrapper.httpx_client.request(
            "upload",
            method="POST",
            data={
                "metadata": metadata,
            },
            files={
                **({"file": file} if file is not None else {}),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UploadResponse,
                    parse_obj_as(
                        type_=UploadResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def start_vector_update(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[VectorUpdateResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[VectorUpdateResponse]
            Vector update started successfully
        """
        _response = self._client_wrapper.httpx_client.request(
            "start_vector_update",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VectorUpdateResponse,
                    parse_obj_as(
                        type_=VectorUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawConcreteApi:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_health(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[HealthStatus]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[HealthStatus]
            OK
        """
        _response = await self._client_wrapper.httpx_client.request(
            "health",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    HealthStatus,
                    parse_obj_as(
                        type_=HealthStatus,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def upload_file(
        self,
        *,
        file: typing.Optional[core.File] = OMIT,
        metadata: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[UploadResponse]:
        """
        Parameters
        ----------
        file : typing.Optional[core.File]
            See core.File for more documentation

        metadata : typing.Optional[str]
            Optional JSON metadata associated with the file

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[UploadResponse]
            File successfully uploaded
        """
        _response = await self._client_wrapper.httpx_client.request(
            "upload",
            method="POST",
            data={
                "metadata": metadata,
            },
            files={
                **({"file": file} if file is not None else {}),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    UploadResponse,
                    parse_obj_as(
                        type_=UploadResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def start_vector_update(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[VectorUpdateResponse]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[VectorUpdateResponse]
            Vector update started successfully
        """
        _response = await self._client_wrapper.httpx_client.request(
            "start_vector_update",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VectorUpdateResponse,
                    parse_obj_as(
                        type_=VectorUpdateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
